#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys

from distutils.core import setup

import omnijson


if sys.argv[-1] == 'publish':
    os.system("python setup.py sdist upload")
    sys.exit()

if sys.argv[-1] == 'speedups':
    try:
        import pip
    except ImportError:
        print('Pip required.')
        sys.exit(1)

    os.system('pip install ujson')
    sys.exit()

setup(
    name='omnijson',
    version=omnijson.__version__,
    description='Wraps the best JSON installed, falling back on an internal simplejson.',
    long_description=open('README.rst').read(),
    author='Kenneth Reitz',
    author_email='me@kennethreitz.com',
    url='https://github.com/kennethreitz/omnijson',
    packages= [
        'omnijson',
        'omnijson.packages',
        'omnijson.packages.simplejson'
    ],
    license='MIT',
    classifiers=(
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        # 'Programming Language :: Python :: 3.0',
        # 'Programming Language :: Python :: 3.1',
        # 'Programming Language :: Python :: 3.2',
    ),
)



# -*- coding: utf-8 -*-

from .packages import simplejson as internal_json
from .packages.simplejson.ordered_dict import OrderedDict

engine = None
_engine = None


_json_map = OrderedDict()

_json_map['ujson'] = ['loads', 'dumps', ValueError]
_json_map['yajl'] = ['loads', 'dumps', (TypeError, ValueError)]
_json_map['jsonlib2'] = ['read', 'write', ValueError]
_json_map['jsonlib'] = ['read', 'write', ValueError]
_json_map['simplejson'] = ['loads', 'dumps', (TypeError, ValueError)]
_json_map['json'] = ['loads', 'dumps', (TypeError, ValueError)]
_json_map['simplejson_from_packages'] = ['loads', 'dumps', ValueError]


def _import(engine):
    try:
        if '_from_' in engine:
            engine, package = engine.split('_from_')
            m = __import__(package, globals(), locals(), [engine], -1)
            return getattr(m, engine)

        return __import__(engine)

    except ImportError:
        return False


def loads(s):
    """Loads JSON object."""

    try:
        try:
            return _engine[0](s, **kwargs)
        except TypeError:
            return _engine[0](s)

    except _engine[2], why:
        raise JSONError(why)



def dumps(o, **kwargs):
    """Dumps JSON object."""

    try:
        try:
            return _engine[1](o, **kwargs)
        except TypeError:
            return _engine[1](o)

    except _engine[2], why:
        raise JSONError(why)



class JSONError(ValueError):
    """JSON Failed."""


for k, v in _json_map.items():

    __engine = _import(k)

    if __engine:
        engine, _engine = k, v

        for i in (0, 1):
            _engine[i] = getattr(__engine, _engine[i])

        break
